@@ -13,9 +13,9 @@ def author_ipr(author_id, output_format='dictionary', pretty_print=None, xml_lib
     page_info = soup.select('.uk-width-large-1-2.table-footer')
     n_page = int(page_info[0].text.strip().split()[3])
     threads = []
-    worker_result = []
+    worker_result = parse(soup)
 
-    for page in range(1, n_page + 1):
+    for page in range(2, n_page + 1):
         thread = threading.Thread(target=worker, args=(author_id, page, worker_result))
 
         thread.start()
@@ -28,24 +28,33 @@ def author_ipr(author_id, output_format='dictionary', pretty_print=None, xml_lib
 
 
 def worker(author_id, page, worker_result):
-    page_url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=ipr'
-    page_html = get(page_url)
-    page_soup = BeautifulSoup(page_html.content, 'html.parser')
-    trs = page_soup.select('table.uk-table tr')
+    url = f'http://sinta.ristekbrin.go.id/authors/detail?page={page}&id={author_id}&view=ipr'
+    html = get(url)
+    soup = BeautifulSoup(html.content, 'html.parser')
+    data = parse(soup)
 
-    for tr in trs:
-        h4 = tr.select('h4.uk-text-primary')
+    worker_result.extend(data)
+
+
+def parse(soup):
+    rows = soup.select('table.uk-table tr')
+    result = []
+
+    for row in rows:
+        h4 = row.select('h4.uk-text-primary')
 
         if not h4:
             continue
 
         h4 = h4[0]
-        info = tr.select('.uk-text-success')
+        info = row.select('.uk-text-success')
 
-        worker_result.append({
+        result.append({
             'id': info[0].text.strip(),
             'title': h4.text.strip(),
             'category': info[1].text.strip(),
             'year': info[2].text.strip(),
             'holder': info[3].text.strip()
         })
+
+    return result
